==> eagle-i-search-ncbi-utils-1.1-MS1.00-sources.jar: org/eaglei/search/provider/ncbi/taxonomy/NCBITaxonomyProvider.java <==
package org.eaglei.search.provider.ncbi.taxonomy;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.eaglei.search.provider.ncbi.NCBIDBProvider;
import org.eaglei.search.provider.ncbi.NCBIEUtils.DocSummary;
import org.eaglei.search.provider.ncbi.NCBIEUtils.Item;

/**
 * Contains logic for querying NCBI Taxonomy via EUtils.
 *
 * @author rfrost
 */
public final class NCBITaxonomyProvider extends NCBIDBProvider {

    private static final Log logger = LogFactory.getLog(NCBITaxonomyProvider.class);
    private static final boolean DEBUG = logger.isDebugEnabled();
    
    public static final String TAXONOMY = "taxonomy";
    public static final String TAXONOMY_URL = "http://www.ncbi.nlm.nih.gov/Taxonomy/Browser/wwwtax.cgi?id=";
    public static final String NCBI_TAXONOMY_NAME = "NCBI Taxonomy";
    
    public static final String TAX_ID= "TaxId";
    public static final String COMMON_NAME = "CommonName";
    public static final String SCI_NAME = "ScientificName";
    
    public NCBITaxonomyProvider() {
        super(TAXONOMY);
    }  

    public static class TaxonomySummary {
        public String id;
        public String url;
        public Item commonName;
        public Item sciName;
        public String label;
        
        public TaxonomySummary(DocSummary sum) {
            this.id = sum.id;
            this.url = TAXONOMY_URL + id;
            this.commonName= sum.items.get(COMMON_NAME).get(0);
            this.sciName= sum.items.get(SCI_NAME).get(0);
            this.label = commonName.value;
        }
    }
}

==> eagle-i-search-ncbi-utils-1.2-MS2.00-sources.jar: org/eaglei/search/provider/ncbi/taxonomy/NCBITaxonomyProvider.java <==
package org.eaglei.search.provider.ncbi.taxonomy;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.eaglei.search.provider.ncbi.ESummary.ESummaryResult;
import org.eaglei.search.provider.ncbi.ESummary.Item;
import org.eaglei.search.provider.ncbi.NCBIDBProvider;

/**
 * Contains logic for querying NCBI Taxonomy via EUtils.
 *
 * @author rfrost
 */
public final class NCBITaxonomyProvider extends NCBIDBProvider {

    private static final Log logger = LogFactory.getLog(NCBITaxonomyProvider.class);
    private static final boolean DEBUG = logger.isDebugEnabled();
    
    public static final String TAXONOMY = "taxonomy";
    public static final String TAXONOMY_URL = "http://www.ncbi.nlm.nih.gov/Taxonomy/Browser/wwwtax.cgi?id=";
    public static final String NCBI_TAXONOMY_NAME = "NCBI Taxonomy";
    
    public static final String TAX_ID= "TaxId";
    public static final String COMMON_NAME = "CommonName";
    public static final String SCI_NAME = "ScientificName";
    
    public NCBITaxonomyProvider() {
        super(TAXONOMY);
    }  

    public static class TaxonomySummary {
        public String id;
        public String url;
        public Item commonName;
        public Item sciName;
        public String label;
        
        public TaxonomySummary(ESummaryResult sum) {
            this.id = sum.id;
            this.url = TAXONOMY_URL + id;
            this.commonName= sum.items.get(COMMON_NAME).get(0);
            this.sciName= sum.items.get(SCI_NAME).get(0);
            this.label = commonName.value;
        }
    }
}
